{
    "$graph": [
        {
            "class": "Workflow",
            "label": "ProGENI",
            "doc": "network-guided gene prioritization method implementation by KnowEnG that ranks gene measurements by their correlation to observed phenotypes",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/genomic_spreadsheet_file",
                    "label": "Genomic Spreadsheet",
                    "doc": "the genomic spreadsheet input for the pipeline",
                    "type": "File"
                },
                {
                    "id": "#main/phenotypic_spreadsheet_file",
                    "label": "Phenotypic Spreadsheet",
                    "doc": "spreadsheet of phenotypic data with samples as rows and phenotypes as columns",
                    "type": "File"
                },
                {
                    "id": "#main/correlation_measure",
                    "label": "Correlation Measure",
                    "doc": "keyword for correlation metric, one of either ['t_test', 'pearson']",
                    "type": "string"
                },
                {
                    "id": "#main/num_bootstraps",
                    "label": "Number of bootstraps",
                    "doc": "number of types to sample the data and repeat the analysis",
                    "type": "int",
                    "default": 0
                },
                {
                    "id": "#main/use_network",
                    "label": "Use Network Flag",
                    "doc": "whether or not to use a network for ProGENI",
                    "type": "boolean",
                    "default": true
                },
                {
                    "id": "#main/edge_type",
                    "label": "Subnetwork Edge Type",
                    "doc": "the edge type keyword for the subnetwork of interest",
                    "type": "string",
                    "default": "STRING_experimental"
                },
                {
                    "id": "#main/network_type",
                    "label": "Subnetwork Class",
                    "doc": "the type of subnetwork",
                    "type": "string",
                    "default": "Gene"
                },
                {
                    "id": "#main/taxonid",
                    "label": "Species TaxonID",
                    "doc": "taxon id of species related to genomic spreadsheet",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "9606"
                },
                {
                    "id": "#main/redis_host",
                    "label": "RedisDB host URL",
                    "doc": "url of Redis db",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "knowredis.knoweng.org"
                },
                {
                    "id": "#main/redis_port",
                    "label": "RedisDB Port",
                    "doc": "port for Redis db",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 6379
                },
                {
                    "id": "#main/redis_pass",
                    "label": "RedisDB AuthStr",
                    "doc": "password for Redis db",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "KnowEnG"
                }
            ],
            "steps": [
                {
                    "id": "#main/kn_fetcher",
                    "run": "#kn_fetcher.cwl",
                    "in": [
                        {
                            "id": "#main/kn_fetcher/get_network",
                            "source": "#main/use_network"
                        },
                        {
                            "id": "#main/kn_fetcher/network_type",
                            "source": "#main/network_type"
                        },
                        {
                            "id": "#main/kn_fetcher/taxonid",
                            "source": "#main/taxonid"
                        },
                        {
                            "id": "#main/kn_fetcher/edge_type",
                            "source": "#main/edge_type"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/kn_fetcher/network_edge_file"
                        },
                        {
                            "id": "#main/kn_fetcher/cmd_log_file"
                        },
                        {
                            "id": "#main/kn_fetcher/node_map_file"
                        },
                        {
                            "id": "#main/kn_fetcher/network_metadata_file"
                        }
                    ]
                },
                {
                    "id": "#main/data_cleaning",
                    "run": "#data_cleaning.cwl",
                    "in": [
                        {
                            "id": "#main/data_cleaning/pipeline_type",
                            "valueFrom": "gene_prioritization_pipeline"
                        },
                        {
                            "id": "#main/data_cleaning/genomic_spreadsheet_file",
                            "source": "#main/genomic_spreadsheet_file"
                        },
                        {
                            "id": "#main/data_cleaning/taxonid",
                            "source": "#main/taxonid"
                        },
                        {
                            "id": "#main/data_cleaning/phenotypic_spreadsheet_file",
                            "source": "#main/phenotypic_spreadsheet_file"
                        },
                        {
                            "id": "#main/data_cleaning/gene_prioritization_corr_measure",
                            "source": "#main/correlation_measure"
                        },
                        {
                            "id": "#main/data_cleaning/redis_host",
                            "source": "#main/redis_host"
                        },
                        {
                            "id": "#main/data_cleaning/redis_port",
                            "source": "#main/redis_port"
                        },
                        {
                            "id": "#main/data_cleaning/redis_pass",
                            "source": "#main/redis_pass"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/data_cleaning/cleaning_log_file"
                        },
                        {
                            "id": "#main/data_cleaning/gene_map_file"
                        },
                        {
                            "id": "#main/data_cleaning/gene_unmap_file"
                        },
                        {
                            "id": "#main/data_cleaning/cleaning_yml_file"
                        },
                        {
                            "id": "#main/data_cleaning/clean_genomic_file"
                        },
                        {
                            "id": "#main/data_cleaning/clean_phenotypic_file"
                        }
                    ]
                },
                {
                    "id": "#main/gp_runner",
                    "run": "#gp_runner.cwl",
                    "in": [
                        {
                            "id": "#main/gp_runner/use_network",
                            "source": "#main/use_network"
                        },
                        {
                            "id": "#main/gp_runner/genomic_file",
                            "source": "#main/data_cleaning/clean_genomic_file"
                        },
                        {
                            "id": "#main/gp_runner/phenotypic_file",
                            "source": "#main/data_cleaning/clean_phenotypic_file"
                        },
                        {
                            "id": "#main/gp_runner/correlation_measure",
                            "source": "#main/correlation_measure"
                        },
                        {
                            "id": "#main/gp_runner/network_file",
                            "source": "#main/kn_fetcher/network_edge_file"
                        },
                        {
                            "id": "#main/gp_runner/num_bootstraps",
                            "source": "#main/num_bootstraps"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/gp_runner/top100_genes_matrix"
                        },
                        {
                            "id": "#main/gp_runner/top_ranked_genes"
                        },
                        {
                            "id": "#main/gp_runner/ranked_genes_file"
                        },
                        {
                            "id": "#main/gp_runner/params_yml"
                        }
                    ]
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "id": "#main/network_edge_file",
                    "label": "Subnetwork Edge File",
                    "doc": "4 column format for subnetwork for single edge type and species",
                    "type": "File",
                    "outputSource": "#main/kn_fetcher/network_edge_file"
                },
                {
                    "id": "#main/fetch_cmd_log_file",
                    "label": "Fetch Command Log File",
                    "doc": "Fetch Command Log File",
                    "type": "File",
                    "outputSource": "#main/kn_fetcher/cmd_log_file"
                },
                {
                    "id": "#main/cleaning_log_file",
                    "label": "Cleaning Log File",
                    "doc": "information on souce of errors for cleaning pipeline",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/data_cleaning/cleaning_log_file"
                },
                {
                    "id": "#main/clean_genomic_file",
                    "label": "Clean Genomic Spreadsheet",
                    "doc": "matrix with gene names mapped and data cleaned",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/data_cleaning/clean_genomic_file"
                },
                {
                    "id": "#main/clean_phenotypic_file",
                    "label": "Clean Phenotypic Spreadsheet",
                    "doc": "phenotype file prepared for pipeline",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/data_cleaning/clean_phenotypic_file"
                },
                {
                    "id": "#main/gene_map_file",
                    "label": "Genomic Spreadsheet Map",
                    "doc": "two columns for internal gene ids and original gene ids",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/data_cleaning/gene_map_file"
                },
                {
                    "id": "#main/gene_unmap_file",
                    "label": "Genomic Spreadsheet Unmapped Genes",
                    "doc": "two columns for original gene ids and unmapped reason code",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/data_cleaning/gene_unmap_file"
                },
                {
                    "id": "#main/cleaning_yml_file",
                    "label": "Cleanup Parameter File",
                    "doc": "data cleaning parameters in yaml format",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/data_cleaning/cleaning_yml_file"
                },
                {
                    "id": "#main/top100_genes_matrix",
                    "label": "top100 Genes File",
                    "doc": "Membership spreadsheet with phenotype columns and gene rows",
                    "type": "File",
                    "outputSource": "#main/gp_runner/top100_genes_matrix"
                },
                {
                    "id": "#main/top_ranked_genes",
                    "label": "Lists of Top Genes",
                    "doc": "Lists of Top Genes",
                    "type": "File",
                    "outputSource": "#main/gp_runner/top_ranked_genes"
                },
                {
                    "id": "#main/ranked_genes_file",
                    "label": "Ranked Genes File",
                    "doc": "Ranked Genes File",
                    "type": "File",
                    "outputSource": "#main/gp_runner/ranked_genes_file"
                },
                {
                    "id": "#main/params_yml",
                    "label": "Configuration Parameter File",
                    "doc": "contains the values used in analysis",
                    "type": "File",
                    "outputSource": "#main/gp_runner/params_yml"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#data_cleaning.cwl",
            "label": "Pipeline Preprocessing",
            "doc": "checks the inputs of a pipeline for potential sources of errors",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "knowengdev/data_cleanup_pipeline:07_26_2017"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 5000,
                    "outdirMin": 512000
                }
            ],
            "inputs": [
                {
                    "id": "#data_cleaning.cwl/data_cleaning/pipeline_type",
                    "label": "Name of Pipeline",
                    "doc": "keywork name of pipeline from following list ['gene_prioritization_pipeline', 'samples_clustering_pipeline', 'geneset_characterization_pipeline']",
                    "type": "string"
                },
                {
                    "id": "#data_cleaning.cwl/data_cleaning/genomic_spreadsheet_file",
                    "label": "Genomic Spreadsheet",
                    "doc": "the genomic spreadsheet input for the pipeline",
                    "type": "File"
                },
                {
                    "id": "#data_cleaning.cwl/data_cleaning/taxonid",
                    "label": "Species TaxonID",
                    "doc": "taxon id of species related to genomic spreadsheet",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "9606"
                },
                {
                    "id": "#data_cleaning.cwl/data_cleaning/phenotypic_spreadsheet_file",
                    "label": "Phenotypic Spreadsheet",
                    "doc": "the phenotypic spreadsheet input for the pipeline [may be optional]",
                    "type": [
                        "null",
                        "File"
                    ],
                    "default": {
                        "class": "File",
                        "location": "https://raw.githubusercontent.com/bin/sh"
                    }
                },
                {
                    "id": "#data_cleaning.cwl/data_cleaning/gene_prioritization_corr_measure",
                    "label": "GP correlation measure",
                    "doc": "if pipeline_type=='gene_prioritization_pipeline', then must be one of either ['t_test', 'pearson']",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "missing"
                },
                {
                    "id": "#data_cleaning.cwl/data_cleaning/redis_host",
                    "label": "RedisDB host URL",
                    "doc": "url of Redis db",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "knowredis.knoweng.org"
                },
                {
                    "id": "#data_cleaning.cwl/data_cleaning/redis_port",
                    "label": "RedisDB Port",
                    "doc": "port for Redis db",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 6379
                },
                {
                    "id": "#data_cleaning.cwl/data_cleaning/redis_pass",
                    "label": "RedisDB AuthStr",
                    "doc": "password for Redis db",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "KnowEnG"
                },
                {
                    "id": "#data_cleaning.cwl/data_cleaning/source_hint",
                    "label": "ID Source Hint",
                    "doc": "suggestion for ID source database used to resolve ambiguities in mapping",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": ""
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "shellQuote": false,
                    "valueFrom": "echo \"\npipeline_type: $(inputs.pipeline_type)\nspreadsheet_name_full_path: $(inputs.genomic_spreadsheet_file.path)\ntaxonid: '$(inputs.taxonid)'\nredis_credential:\n  host: $(inputs.redis_host)\n  password: $(inputs.redis_pass)\n  port: $(inputs.redis_port)\nsource_hint: '$(inputs.source_hint)'\nresults_directory: ./\n\" > run_cleanup.yml && \\\nif [ \"$(inputs.phenotypic_spreadsheet_file.nameroot)\" != \"sh\" ]; then \\\n  echo \"phenotype_name_full_path: $(inputs.phenotypic_spreadsheet_file.path)\" >> run_cleanup.yml; fi && \\\nif [ \"$(inputs.pipeline_type)\" = \"gene_prioritization_pipeline\" ]; then \\\n  echo \"correlation_measure: $(inputs.gene_prioritization_corr_measure)\" >> run_cleanup.yml; fi && \\\ndate && python3 /home/src/data_cleanup.py -run_directory ./ -run_file run_cleanup.yml && date"
                }
            ],
            "outputs": [
                {
                    "id": "#data_cleaning.cwl/data_cleaning/cleaning_log_file",
                    "label": "Cleaning Log File",
                    "doc": "information on souce of errors for cleaning pipeline",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "log_*_pipeline.yml"
                    }
                },
                {
                    "id": "#data_cleaning.cwl/data_cleaning/clean_genomic_file",
                    "label": "Clean Genomic Spreadsheet",
                    "doc": "matrix with gene names mapped and data cleaned",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.genomic_spreadsheet_file.nameroot)_ETL.tsv"
                    }
                },
                {
                    "id": "#data_cleaning.cwl/data_cleaning/clean_phenotypic_file",
                    "label": "Clean Phenotypic Spreadsheet",
                    "doc": "phenotype file prepared for pipeline",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.phenotypic_spreadsheet_file.nameroot)_ETL.tsv"
                    }
                },
                {
                    "id": "#data_cleaning.cwl/data_cleaning/gene_map_file",
                    "label": "Genomic Spreadsheet Map",
                    "doc": "two columns for internal gene ids and original gene ids",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_MAP.tsv"
                    }
                },
                {
                    "id": "#data_cleaning.cwl/data_cleaning/gene_unmap_file",
                    "label": "Genomic Spreadsheet Unmapped Genes",
                    "doc": "two columns for original gene ids and unmapped reason code",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_UNMAPPED.tsv"
                    }
                },
                {
                    "id": "#data_cleaning.cwl/data_cleaning/cleaning_yml_file",
                    "label": "Cleanup Parameter File",
                    "doc": "data cleaning parameters in yaml format",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "run_cleanup.yml"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "ProGENI",
            "doc": "network-guided gene prioritization method implementation by KnowEnG that ranks gene measurements by their correlation to observed phenotypes",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "knowengdev/gene_prioritization_pipeline:07_26_2017"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 5000,
                    "outdirMin": 512000
                }
            ],
            "inputs": [
                {
                    "id": "#gp_runner.cwl/genomic_file",
                    "label": "Genomic Spreadsheet File",
                    "doc": "spreadsheet of genomic data with samples as columns and genes as rows",
                    "type": "File"
                },
                {
                    "id": "#gp_runner.cwl/phenotypic_file",
                    "label": "Phenotypic File",
                    "doc": "spreadsheet of phenotypic data with samples as rows and phenotypes as columns",
                    "type": "File"
                },
                {
                    "id": "#gp_runner.cwl/correlation_measure",
                    "label": "Correlation Measure",
                    "doc": "keyword for correlation metric, i.e. t_test or pearson",
                    "type": "string"
                },
                {
                    "id": "#gp_runner.cwl/use_network",
                    "label": "Use Network Flag",
                    "doc": "whether or not to use a network for ProGENI",
                    "type": "boolean",
                    "default": true
                },
                {
                    "id": "#gp_runner.cwl/network_file",
                    "label": "Network File",
                    "doc": "gene-gene network of interactions in edge format [optional]",
                    "type": [
                        "null",
                        "File"
                    ],
                    "default": {
                        "class": "File",
                        "location": "https://raw.githubusercontent.com/bin/sh"
                    }
                },
                {
                    "id": "#gp_runner.cwl/num_bootstraps",
                    "label": "Number of bootstraps",
                    "doc": "number of types to sample the data and repeat the analysis",
                    "type": "int",
                    "default": 0
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "shellQuote": false,
                    "valueFrom": "echo \"\nspreadsheet_name_full_path: $(inputs.genomic_file.path)\nphenotype_name_full_path: $(inputs.phenotypic_file.path)\ncorrelation_measure: $(inputs.correlation_measure)\nresults_directory: ./\ntop_beta_of_sort: 100\ndrop_method: drop_NA\n\" > run_params.yml && \\\nif [ \"$(inputs.use_network)\" = \"true\" ]; then \\\n  echo \"gg_network_name_full_path: $(inputs.network_file.path)\" >> run_params.yml; \\\n  echo \"rwr_convergence_tolerence: 0.0001\" >> run_params.yml; \\\n  echo \"rwr_max_iterations: 100\" >> run_params.yml; \\\n  echo \"rwr_restart_probability: 0.5\" >> run_params.yml; \\\nfi && \\\nif [ $(inputs.num_bootstraps) -ne 0 ]; then \\\n  echo \"number_of_bootstraps: $(inputs.num_bootstraps)\" >> run_params.yml; \\\n  echo \"cols_sampling_fraction: 0.8\" >> run_params.yml; \\\n  echo \"rows_sampling_fraction: 1.0\" >> run_params.yml; \\\nfi && \\\nif [ \"$(inputs.use_network)\" = \"true\" ] && [ $(inputs.num_bootstraps) -ne 0 ]; then \\\n  echo \"method: bootstrap_net_correlation\" >> run_params.yml; \\\nelif [ \"$(inputs.use_network)\" = \"true\" ] && [ $(inputs.num_bootstraps) -eq 0 ]; then \\\n  echo \"method: net_correlation\" >> run_params.yml; \\\nelif [ \"$(inputs.use_network)\" = \"false\" ] && [ $(inputs.num_bootstraps) -ne 0 ]; then \\\n  echo \"method: bootstrap_correlation\" >> run_params.yml; \\\nelif [ \"$(inputs.use_network)\" = \"false\" ] && [ $(inputs.num_bootstraps) -eq 0 ]; then \\\n  echo \"method: correlation\" >> run_params.yml; \\\nfi && \\\ndate && python3 /home/src/gene_prioritization.py -run_directory ./ -run_file run_params.yml && cat *_viz.tsv > combo_results.txt && mv ranked_genes*.tsv ranked_genes_download.tsv && mv top_genes*.tsv top_genes_download.tsv && date"
                }
            ],
            "outputs": [
                {
                    "id": "#gp_runner.cwl/top100_genes_matrix",
                    "label": "top100 Genes File",
                    "doc": "Membership spreadsheet with phenotype columns and gene rows",
                    "type": "File",
                    "outputBinding": {
                        "glob": "top_genes*.tsv"
                    }
                },
                {
                    "id": "#gp_runner.cwl/top_ranked_genes",
                    "label": "Lists of Top Genes",
                    "doc": "Lists of Top Genes",
                    "type": "File",
                    "outputBinding": {
                        "glob": "ranked_genes*.tsv"
                    }
                },
                {
                    "id": "#gp_runner.cwl/ranked_genes_file",
                    "label": "Ranked Genes File",
                    "doc": "Ranked Genes File",
                    "type": "File",
                    "outputBinding": {
                        "glob": "combo_results.txt"
                    }
                },
                {
                    "id": "#gp_runner.cwl/params_yml",
                    "label": "Configuration Parameter File",
                    "doc": "contains the values used in analysis",
                    "type": "File",
                    "outputBinding": {
                        "glob": "run_params.yml"
                    }
                }
            ],
            "id": "#gp_runner.cwl"
        },
        {
            "class": "CommandLineTool",
            "id": "#kn_fetcher.cwl",
            "label": "Knowledge Network Fetcher",
            "doc": "Retrieve appropriate subnetwork from KnowEnG Knowledge Network from AWS S3 storage",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/cblatti3/kn_fetcher:latest"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 2000,
                    "outdirMin": 512000
                }
            ],
            "inputs": [
                {
                    "id": "#kn_fetcher.cwl/kn_fetcher/get_network",
                    "label": "Get Network Flag",
                    "doc": "whether or not to get the network",
                    "type": "boolean",
                    "default": true
                },
                {
                    "id": "#kn_fetcher.cwl/kn_fetcher/bucket",
                    "label": "AWS S3 Bucket Name",
                    "doc": "the aws s3 bucket",
                    "type": "string",
                    "default": "KnowNets/KN-20rep-1706/userKN-20rep-1706"
                },
                {
                    "id": "#kn_fetcher.cwl/kn_fetcher/network_type",
                    "label": "Subnetwork Class",
                    "doc": "the type of subnetwork",
                    "type": "string",
                    "default": "Gene"
                },
                {
                    "id": "#kn_fetcher.cwl/kn_fetcher/taxonid",
                    "label": "Subnetwork Species ID",
                    "doc": "the taxonomic id for the species of interest",
                    "type": "string",
                    "default": "9606"
                },
                {
                    "id": "#kn_fetcher.cwl/kn_fetcher/edge_type",
                    "label": "Subnetwork Edge Type",
                    "doc": "the edge type keyword for the subnetwork of interest",
                    "type": "string",
                    "default": "PPI_physical_association"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "shellQuote": false,
                    "valueFrom": "MYCMD=\"date && if [ \\\"$(inputs.get_network)\\\" = \\\"true\\\" ]; then /home/kn_fetcher.sh $(inputs.bucket) $(inputs.network_type) $(inputs.taxonid) $(inputs.edge_type); else touch empty.edge; fi && date\" && echo $MYCMD > run_fetch.cmd && eval $MYCMD"
                }
            ],
            "outputs": [
                {
                    "id": "#kn_fetcher.cwl/kn_fetcher/network_edge_file",
                    "label": "Subnetwork Edge File",
                    "doc": "4 column format for subnetwork for single edge type and species",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.edge"
                    }
                },
                {
                    "id": "#kn_fetcher.cwl/kn_fetcher/cmd_log_file",
                    "label": "Command Log File",
                    "doc": "log of fetch command",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "run_fetch.cmd"
                    }
                },
                {
                    "id": "#kn_fetcher.cwl/kn_fetcher/node_map_file",
                    "label": "Node Map File",
                    "doc": "5 column node map with [original_node_id, mapped_node_id, node_type, node_alias, node_description]",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.node_map"
                    }
                },
                {
                    "id": "#kn_fetcher.cwl/kn_fetcher/network_metadata_file",
                    "label": "Network Metadata File",
                    "doc": "yaml format describing network contents",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.metadata"
                    }
                }
            ]
        }
    ],
    "cwlVersion": "v1.0"
}
